package com.gic.store.service;

import com.gic.store.dto.StoreDTO;
import com.gic.store.dto.StoreStrategyDTO;
import com.gic.store.entity.TabStore;
import com.gic.store.entity.TabStoreStrategy;
import com.github.pagehelper.Page;

import java.util.List;

/**
 * @author guojx
 * @date 2019/7/4 9:46 AM
 */
public interface StoreStrategyService {

    /**
     * 新增分组策略
     * @param storeStrategyDTO
     * @return
     */
    int saveStoreGroupStrategy(StoreStrategyDTO storeStrategyDTO);

    /**
     * 是否策略名称重复
     * @param record
     * @return
     */
    boolean isRepeatGroupStrategyName(TabStoreStrategy record);

    /**
     * 根据主键查询
     * @param strategyId
     * @return
     */
    TabStoreStrategy getStoreStrategyById(Integer strategyId);

    /**
     * 查询下一个排序值的属性值
     * @param enterpriseId
     * @param sort
     * @param strategyType
     * @return
     */
    TabStoreStrategy getNextSort(int enterpriseId, double sort, int strategyType);

    /**
     * 查询上一个排序值的属性值
     * @param enterpriseId
     * @param sort
     * @param strategyType
     * @return
     */
    TabStoreStrategy getPrevSort(int enterpriseId, double sort, int strategyType);

    /**
     * 置顶、置底，自定义序号
     * @param strategyId
     * @param enterpriseId
     * @param setValue
     * @param strategyType
     */
    void setStoreStrategySort(int strategyId, int enterpriseId, int setValue, int strategyType);

    double getMinSort(int enterpriseId, int strategyType);

    /**
     * 置底
     * @param enterpriseId
     * @param strategyId
     * @param strategyType
     */
    void sortBottom(int enterpriseId, int strategyId, int strategyType);

    /**
     * 置顶
     * @param enterpriseId
     * @param strategyId
     * @param strategyType
     */
    void sortTopping(int enterpriseId, int strategyId, int strategyType);

    /**
     * 删除分组策略（单条）
     * @param strategyId
     * @return
     */
    int deleteStoreGroupStrategy(int strategyId);

    /**
     * 修改分组策略
     * @param storeStrategyDTO
     * @return
     */
    int modifyStoreGroupStrategy(StoreStrategyDTO storeStrategyDTO);

    /**
     * 分页查询数据
     * @param enterpriseId
     * @param search
     * @param strategyType
     * @param pageNum
     * @param pageSize
     * @return
     */
    Page<TabStoreStrategy> listStoreStrategy(int enterpriseId, String search, int strategyType, Integer pageNum, Integer pageSize);

    /**
     * 查询策略列表数据
     * @param enterpriseId
     * @param strategyType
     * @return
     */
    List<TabStoreStrategy> listStoreStrategy(int enterpriseId, int strategyType);

    void updateSortById(int strategyId, double sort);

    /**
     * 验证是否命中，如果命中，返回的result值就是命中值，否则是空字符串
     * @param storeId
     * @param enterpriseId
     * @param strategyType
     * @return
     */
    String isHitStrategy(int storeId, int enterpriseId, int strategyType);

    /**
     * 验证是否命中，如果命中，返回的result值就是命中值，否则是空字符串
     * @param storeDTO
     * @param strategyType 1:门店启用状态策略 2：分组策略
     * @return
     */
    String isHitStrategy(StoreDTO storeDTO, int strategyType);

}
